@@ -1,15 +1,16 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level
 #of this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 from trytond.model import ModelWorkflow, ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.pyson import Not, Equal, Eval, Or, Bool
 from trytond.backend import TableHandler
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 STATES = {
     'readonly': Not(Equal(Eval('state'), 'draft')),
 }
+DEPENDS = ['state']
 
 
 class Inventory(ModelWorkflow, ModelSQL, ModelView):
@@ -23,21 +24,25 @@ class Inventory(ModelWorkflow, ModelSQL, ModelView):
         domain=[('type', '=', 'storage')], states={
             'readonly': Or(Not(Equal(Eval('state'), 'draft')),
                 Bool(Eval('lines'))),
-        })
+            },
+        depends=['state', 'lines'])
     date = fields.Date('Date', required=True, states={
             'readonly': Or(Not(Equal(Eval('state'), 'draft')),
                 Bool(Eval('lines'))),
-        })
+            },
+        depends=['state', 'lines'])
     lost_found = fields.Many2One(
         'stock.location', 'Lost and Found', required=True,
-        domain=[('type', '=', 'lost_found')], states=STATES)
+        domain=[('type', '=', 'lost_found')], states=STATES, depends=DEPENDS)
     lines = fields.One2Many(
-        'stock.inventory.line', 'inventory', 'Lines', states=STATES)
+        'stock.inventory.line', 'inventory', 'Lines', states=STATES,
+        depends=DEPENDS)
     company = fields.Many2One('company.company', 'Company', required=True,
         states={
             'readonly': Or(Not(Equal(Eval('state'), 'draft')),
                 Bool(Eval('lines'))),
-        })
+            },
+        depends=['state', 'lines'])
     state = fields.Selection([
         ('draft', 'Draft'),
         ('done', 'Done'),
@@ -60,46 +65,44 @@ class Inventory(ModelWorkflow, ModelSQL, ModelView):
         return 'draft'
 
     def default_date(self):
-        date_obj = self.pool.get('ir.date')
+        date_obj = Pool().get('ir.date')
         return date_obj.today()
 
     def default_company(self):
         return Transaction().context.get('company') or False
 
     def default_lost_found(self):
-        location_obj = self.pool.get('stock.location')
+        location_obj = Pool().get('stock.location')
         location_ids = location_obj.search(self.lost_found.domain)
         if len(location_ids) == 1:
             return location_ids[0]
         return False
 
-    def set_state_draft(self, inventory_id):
-        self.write(inventory_id, {
+    def wkf_draft(self, inventory):
+        self.write(inventory.id, {
             'state': 'draft',
             })
 
-    def set_state_cancel(self, inventory_id):
-        line_obj = self.pool.get("stock.inventory.line")
-        inventory = self.browse(inventory_id)
+    def wkf_cancel(self, inventory):
+        line_obj = Pool().get("stock.inventory.line")
         line_obj.cancel_move(inventory.lines)
-        self.write(inventory_id, {
+        self.write(inventory.id, {
             'state': 'cancel',
             })
 
-    def set_state_done(self, inventory_id):
-        date_obj = self.pool.get('ir.date')
-        line_obj = self.pool.get('stock.inventory.line')
-        inventory = self.browse(inventory_id)
+    def wkf_done(self, inventory):
+        date_obj = Pool().get('ir.date')
+        line_obj = Pool().get('stock.inventory.line')
 
         for line in inventory.lines:
             line_obj.create_move(line)
-        self.write(inventory_id, {
+        self.write(inventory.id, {
             'state': 'done',
             })
 
     def copy(self, ids, default=None):
-        date_obj = self.pool.get('ir.date')
-        line_obj = self.pool.get('stock.inventory.line')
+        date_obj = Pool().get('ir.date')
+        line_obj = Pool().get('stock.inventory.line')
 
         int_id = False
         if isinstance(ids, (int, long)):
@@ -134,9 +137,10 @@ class Inventory(ModelWorkflow, ModelSQL, ModelView):
         :param ids: the ids of stock.inventory
         :param context: the context
         '''
-        line_obj = self.pool.get('stock.inventory.line')
-        product_obj = self.pool.get('product.product')
-        uom_obj = self.pool.get('product.uom')
+        pool = Pool()
+        line_obj = pool.get('stock.inventory.line')
+        product_obj = pool.get('product.product')
+        uom_obj = pool.get('product.uom')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -222,8 +226,8 @@ class InventoryLine(ModelSQL, ModelView):
         return 2
 
     def on_change_product(self, vals):
-        product_obj = self.pool.get('product.product')
-        uom_obj = self.pool.get('product.uom')
+        product_obj = Pool().get('product.product')
+        uom_obj = Pool().get('product.uom')
         res = {}
         res['unit_digits'] = 2
         if vals.get('product'):
@@ -246,7 +250,7 @@ class InventoryLine(ModelSQL, ModelView):
         return res
 
     def cancel_move(self, lines):
-        move_obj = self.pool.get('stock.move')
+        move_obj = Pool().get('stock.move')
         move_obj.write( [l.move.id for l in lines if l.move], {
             'state': 'cancel',
             })
@@ -262,8 +266,12 @@ class InventoryLine(ModelSQL, ModelView):
         :param line: a BrowseRecord of inventory.line
         :return: the stock.move id or None
         '''
-        move_obj = self.pool.get('stock.move')
-        delta_qty = line.expected_quantity - line.quantity
+        move_obj = Pool().get('stock.move')
+        uom_obj = Pool().get('product.uom')
+
+        delta_qty = uom_obj.compute_qty(line.uom,
+            line.expected_quantity - line.quantity,
+            line.uom)
         if delta_qty == 0.0:
             return
         from_location = line.inventory.location.id
@@ -343,7 +351,7 @@ class CompleteInventory(Wizard):
         }
 
     def _complete(self, data):
-        inventory_obj = self.pool.get('stock.inventory')
+        inventory_obj = Pool().get('stock.inventory')
         inventory_obj.complete_lines(data['ids'])
 
         return {}
